@@ -55,7 +55,7 @@ void FalkonSchemeHandler::requestStarted(QWebEngineUrlRequestJob *job)
     knownPages << "about" << "start" << "speeddial" << "config" << "restore";
 
     if (knownPages.contains(job->requestUrl().path()))
-        job->reply(QByteArrayLiteral("text/html"), new FalkonSchemeReply(job));
+        job->reply(QByteArrayLiteral("text/html"), new FalkonSchemeReply(job, job));
     else
         job->fail(QWebEngineUrlRequestJob::UrlInvalid);
 }
@@ -88,9 +88,7 @@ FalkonSchemeReply::FalkonSchemeReply(QWebEngineUrlRequestJob *job, QObject *pare
     , m_job(job)
 {
     m_pageName = m_job->requestUrl().path();
-
-    open(QIODevice::ReadOnly);
-    m_buffer.open(QIODevice::ReadWrite);
+    loadPage();
 }
 
 void FalkonSchemeReply::loadPage()
@@ -98,38 +96,39 @@ void FalkonSchemeReply::loadPage()
     if (m_loaded)
         return;
 
-    QTextStream stream(&m_buffer);
-    stream.setCodec("UTF-8");
+    QString contents;
 
     if (m_pageName == QLatin1String("about")) {
-        stream << aboutPage();
-    }
-    else if (m_pageName == QLatin1String("start")) {
-        stream << startPage();
-    }
-    else if (m_pageName == QLatin1String("speeddial")) {
-        stream << speeddialPage();
-    }
-    else if (m_pageName == QLatin1String("config")) {
-        stream << configPage();
-    }
-    else if (m_pageName == QLatin1String("restore")) {
-        stream << restorePage();
+        contents = aboutPage();
+    } else if (m_pageName == QLatin1String("start")) {
+        contents = startPage();
+    } else if (m_pageName == QLatin1String("speeddial")) {
+        contents = speeddialPage();
+    } else if (m_pageName == QLatin1String("config")) {
+        contents = configPage();
+    } else if (m_pageName == QLatin1String("restore")) {
+        contents = restorePage();
     }
 
-    stream.flush();
-    m_buffer.reset();
+    QMutexLocker lock(&m_mutex);
+    m_buffer.setData(contents.toUtf8());
+    m_buffer.open(QIODevice::ReadOnly);
+    lock.unlock();
+
+    Q_EMIT readyRead();
+
     m_loaded = true;
 }
 
 qint64 FalkonSchemeReply::bytesAvailable() const
 {
+    QMutexLocker lock(&m_mutex);
     return m_buffer.bytesAvailable();
 }
 
 qint64 FalkonSchemeReply::readData(char *data, qint64 maxSize)
 {
-    loadPage();
+    QMutexLocker lock(&m_mutex);
     return m_buffer.read(data, maxSize);
 }
 
@@ -238,7 +237,7 @@ QString FalkonSchemeReply::speeddialPage()
     QString page = dPage;
     SpeedDial* dial = mApp->plugins()->speedDial();
 
-    page.replace(QLatin1String("%INITIAL-SCRIPT%"), dial->initialScript());
+    page.replace(QLatin1String("%INITIAL-SCRIPT%"), dial->initialScript().toUtf8().toBase64());
     page.replace(QLatin1String("%IMG_BACKGROUND%"), dial->backgroundImage());
     page.replace(QLatin1String("%URL_BACKGROUND%"), dial->backgroundImageUrl());
     page.replace(QLatin1String("%B_SIZE%"), dial->backgroundImageSize());
@@ -357,9 +356,9 @@ QString FalkonSchemeReply::configPage()
     page.replace(QLatin1String("%USER-AGENT%"), mApp->webProfile()->httpUserAgent());
 
     QString pluginsString;
-    const QList<Plugins::Plugin> &availablePlugins = mApp->plugins()->getAvailablePlugins();
+    const QList<Plugins::Plugin> &availablePlugins = mApp->plugins()->availablePlugins();
 
-    foreach (const Plugins::Plugin &plugin, availablePlugins) {
+    for (const Plugins::Plugin &plugin : availablePlugins) {
         PluginSpec spec = plugin.pluginSpec;
         pluginsString.append(QString("<tr><td>%1</td><td>%2</td><td>%3</td><td>%4</td></tr>").arg(
                                  spec.name, spec.version, spec.author.toHtmlEscaped(), spec.description));
@@ -373,11 +372,13 @@ QString FalkonSchemeReply::configPage()
 
     QString allGroupsString;
     QSettings* settings = Settings::globalSettings();
-    foreach (const QString &group, settings->childGroups()) {
+    const auto groups = settings->childGroups();
+    for (const QString &group : groups) {
         QString groupString = QString("<tr><th colspan=\"2\">[%1]</th></tr>").arg(group);
         settings->beginGroup(group);
 
-        foreach (const QString &key, settings->childKeys()) {
+        const auto keys = settings->childKeys();
+        for (const QString &key : keys) {
             const QVariant keyValue = settings->value(key);
             QString keyString;
 
