@@ -53,7 +53,7 @@ class FALKON_EXPORT MenuTabs : public QMenu
 {
     Q_OBJECT
 public:
-    explicit MenuTabs(QWidget* parent = 0) : QMenu(parent) {}
+    explicit MenuTabs(QWidget* parent = nullptr) : QMenu(parent) {}
 
 Q_SIGNALS:
     void closeTab(int);
@@ -67,7 +67,7 @@ class FALKON_EXPORT TabWidget : public TabStackedWidget
     Q_OBJECT
 public:
     explicit TabWidget(BrowserWindow *window, QWidget *parent = nullptr);
-    ~TabWidget();
+    ~TabWidget() override;
 
     BrowserWindow *browserWindow() const;
 
