@@ -21,9 +21,7 @@
 #include <QWebEnginePage>
 #include <QtWebEngineCoreVersion>
 
-#if QTWEBENGINECORE_VERSION >= QT_VERSION_CHECK(5, 14, 0)
 #include <QWebEngineFindTextResult>
-#endif
 
 #include "qzcommon.h"
 
@@ -41,8 +39,8 @@ class FALKON_EXPORT SearchToolBar : public QWidget
 {
     Q_OBJECT
 public:
-    explicit SearchToolBar(WebView* view, QWidget* parent = 0);
-    ~SearchToolBar();
+    explicit SearchToolBar(WebView* view, QWidget* parent = nullptr);
+    ~SearchToolBar() override;
 
     void showMinimalInPopupWindow();
 
@@ -58,9 +56,7 @@ public Q_SLOTS:
     void findNext();
     void findPrevious();
 
-#if QTWEBENGINECORE_VERSION >= QT_VERSION_CHECK(5, 14, 0)
     void showSearchResults(const QWebEngineFindTextResult &result);
-#endif
 
     void close();
 
